fractal-engine.session-sqlite

SQLite hot store for canonical operational session facts.

BlobStore remains the byte authority. This namespace stores the small operational rows, append-only transaction batches for the rebuildable Datahike projection, and current-head refs under one local SQLite database.

SQLite hot store for canonical operational session facts.

BlobStore remains the byte authority. This namespace stores the small
operational rows, append-only transaction batches for the rebuildable Datahike
projection, and current-head refs under one local SQLite database.
raw docstring

all-rowsclj

(all-rows root kind)
source

close!clj

(close!)
(close! root)
source

commit!clj

(commit! root rows facts)

Atomically upsert typed rows and append one projection transaction batch.

Atomically upsert typed rows and append one projection transaction batch.
sourceraw docstring

connect!clj

(connect! root)
source

connectionsclj

source

db-pathclj

(db-path root)
source

formatted-ednclj

(formatted-edn value)
source

get-metaclj

(get-meta root k)
source

get-rowclj

(get-row root kind id)
source

init!clj

(init! conn)
source

pathclj

(path dir & parts)
source

put-meta!clj

(put-meta! root k value)
source

put-row!clj

(put-row! root kind id value)
(put-row! root kind id value {:keys [session-id sort-id]})
source

put-rows!clj

(put-rows! root rows)
source

put-tx!clj

(put-tx! root facts)
source

read-ednclj

(read-edn s)
source

root-keyclj

(root-key root)
source

rows-for-sessionclj

(rows-for-session root kind session-id)
source

tx-countclj

(tx-count root)
source

tx-lockclj

(tx-lock root)
source

tx-locksclj

source

txs-afterclj

(txs-after root tx-id)
source

with-txcljmacro

(with-tx [conn root] & body)
source

with-tx*clj

(with-tx* root f)
source

cljdoc builds & hosts documentation for Clojure/Script libraries