Small filesystem/EDN helpers used by store backends.
This namespace is intentionally dumb: it knows nothing about sessions, heads, invocations, or indexes.
Small filesystem/EDN helpers used by store backends. This namespace is intentionally dumb: it knows nothing about sessions, heads, invocations, or indexes.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |