Agent-operable CLI/control plane over fractal.engine.api.
This namespace is intentionally a thin executable seam. It does not introduce product nouns or alternate runtime semantics: commands open a durable SDK session, perform one usage/inspection action, emit JSON/EDN, and close.
Agent-operable CLI/control plane over fractal.engine.api. This namespace is intentionally a thin executable seam. It does not introduce product nouns or alternate runtime semantics: commands open a durable SDK session, perform one usage/inspection action, emit JSON/EDN, and close.
(format-edn value)Pretty-print a complete EDN value for CLI output or generated config files.
Pretty-print a complete EDN value for CLI output or generated config files.
(run-command argv)Run argv, emit to out/err, and return a process-style exit code.
Run argv, emit to *out*/*err*, and return a process-style exit code.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |