Canonical byte storage for durable payloads.
The protocol is intentionally backend-shaped: the local implementation stores content-addressed bytes under a store root, while future implementations can use another physical backend without changing the domain refs.
Canonical byte storage for durable payloads. The protocol is intentionally backend-shaped: the local implementation stores content-addressed bytes under a store root, while future implementations can use another physical backend without changing the domain refs.
(exists? store blob-ref)(put-bytes! store bytes opts)(put-edn! store value opts)(read-bytes store blob-ref)(read-edn store blob-ref)(verify store blob-ref)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |