fractal-engine.process


add-observation!clj

(add-observation! state turn-id content)
source

attached-child-idclj

(attached-child-id n)
source

bounded-fanout-inputsclj

(bounded-fanout-inputs kind cfg inputs)
source

call-blob-pathclj

(call-blob-path call-id part)
source

call-provider!clj

(call-provider! state cfg role call)

A provider completion as a traced call. Returns {:call-id .. :response ..}.

A provider completion as a traced call. Returns {:call-id .. :response ..}.
sourceraw docstring

call-value-ref!clj

(call-value-ref! state call-id part value)
source

child-final-valueclj

(child-final-value result cid child-rel errs)

Validate a sub-session result and return its FINAL value, or throw a typed error. errs supplies the error types for the spawning kind: {:failed .. :no-final ..} (child vs attach). A child's returned value is a claim until it carries a FINAL.

Validate a sub-session result and return its FINAL value, or throw a typed error.
`errs` supplies the error types for the spawning kind: {:failed .. :no-final ..}
(child vs attach). A child's returned value is a claim until it carries a FINAL.
sourceraw docstring

child-finalization-warningclj

(child-finalization-warning max-turns)
source

child-root-configclj

(child-root-config cfg kind)
source

child-session?clj

(child-session? state)
source

child-task-promptclj

(child-task-prompt task)
source

configclj

(config)
(config m)
source

enrich-callclj

(enrich-call state cfg role call call-id)
source

eval-assistant!clj

(eval-assistant! state cfg ns-sym turn-id assistant-message)
source

finalization-warning-step?clj

(finalization-warning-step? state cfg step-n)
source

finish-turn-error!clj

(finish-turn-error! state turn-id err)
source

leaf-requestclj

(leaf-request input query cache-request)
source

make-opsclj

(make-ops state cfg ns-sym)
source

maybe-add-child-finalization-warning!clj

(maybe-add-child-finalization-warning! state cfg turn-id step-n)
source

parse-leafclj

(parse-leaf text mode)
source

prepare-turn!clj

(prepare-turn! state user-message)
source

provider-requestclj

(provider-request messages cache-request)
source

provider-shapeclj

(provider-shape cfg)
source

request-system-hashclj

(request-system-hash request)
source

restore-state-from-snapshot!clj

(restore-state-from-snapshot! state
                              source-dir
                              ns-sym
                              snapshot-row
                              snapshot-blob
                              lineage-kind
                              lineage-parents
                              source-fingerprint)
source

run-loop!clj

(run-loop! state cfg ns-sym turn-id)
source

run-process!clj

(run-process! cfg
              {:keys [dir id kind parent task messages resume-state ns-sym
                      cache-id]
               :as opts})
source

run-task!clj

(run-task! task)
(run-task! cfg task)
source

run-turn-on-state!clj

(run-turn-on-state! state cfg ns-sym user-message)
source

session-cache-idclj

(session-cache-id state)
source

wire-messageclj

(wire-message message)
source

cljdoc builds & hosts documentation for Clojure/Script libraries