SQLite hot store for canonical operational session facts.
BlobStore remains the byte authority. This namespace stores the small operational rows, append-only transaction batches for the rebuildable Datahike projection, and current-head refs under one local SQLite database.
SQLite hot store for canonical operational session facts. BlobStore remains the byte authority. This namespace stores the small operational rows, append-only transaction batches for the rebuildable Datahike projection, and current-head refs under one local SQLite database.
(commit! root rows facts)Atomically upsert typed rows and append one projection transaction batch.
Atomically upsert typed rows and append one projection transaction batch.
(put-row! root kind id value)(put-row! root kind id value {:keys [session-id sort-id]})cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |